@@ -31,7 +31,12 @@ class Listener(neutron.NeutronResource):
     which represent a listening endpoint for the vip.
     """
 
-    support_status = support.SupportStatus(version='6.0.0')
+    support_status = support.SupportStatus(
+        status=support.HIDDEN,
+        version='21.0.0',
+        message=_('Use octavia instead.'),
+        previous_status=support.SupportStatus(version='6.0.0')
+    )
 
     required_service_extension = 'lbaasv2'
 
